/**********************************************************************/
/*                                                                    */
/* Locks / Unlocks RexxMail main & mail folders for each user         */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* This program forms part of the RexxMail package, and may not be    */
/* distributed separately.                                            */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* Use RexxComm.CMD to reformat the comments in this program.         */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* The latest versions of RexxMail and RexxComm can be found at       */
/*               www.degeus.com/rexx                                  */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* This program is released under the terms of the GNU license, see   */
/*               www.gnu.org/copyleft/gpl.html                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* (c) 2000-2001 Marcus C. de Geus                                    */
/*               marcus@degeus.com                                    */
/*               www.degeus.com                                       */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* Use it if you like it. Don't if you don't. No legalese.            */
/*                                                                    */
/**********************************************************************/

signal on halt  /* handle halt condition */

/**********************************************************************/
/* See if we can find and open the location.txt file                  */
/**********************************************************************/

parse source . . ProgSpec  /* get the program name */
ProgDir = filespec('D',ProgSpec)||filespec('P',ProgSpec)  /* get the program directory */

LocFile = ProgDir||'location.txt'  /* the name of the locations file */

if (stream(LocFile,'C','QUERY EXISTS') = '') then  /* if we cannot find the location file */
do
 call beep 333,333  /* signal */
 say 'Could not find "'||LocFile||'"'  /* report */
 call Halt  /* and abort */
end

if (stream(LocFile,'C','OPEN READ') >< 'READY:') then  /* if we cannot open the location file */
do
 call beep 333,333  /* signal */
 say 'Could not open "'||LocFile||'"'  /* report */
 call Halt  /* and abort */
end

/**********************************************************************/
/* Put some info on the screen                                        */
/**********************************************************************/

say 'This program lists the user names and main mail file locations from the'  /* info */
say 'location.txt file in the RexxMail program directory in succession, and'  /* info */
say 'prompts the user to lock, unlock, or skip the entry. Locking the entry'  /* info */
say 'involves adjusting the object settings of the main mail folder and its'  /* info */
say 'subfolders to prevent access to their configuration notebooks, and to'  /* info */
say 'prevent folder objects from being (accidentally) moved, deleted, etc.'  /* info */
say 'Use the unlock option to regain access to these functions.'  /* info */
say ''  /* empty line */
say 'Note that the use of the address import function unlocks any subfolders'  /* info */
say 'of the Addresses folder.'  /* info */
say ''  /* empty line */

/**********************************************************************/
/* Retrieve the main folder location for each user                    */
/**********************************************************************/

UserNames. = ''  /* start with nothing */
Locations. = ''  /* start with nothing */
Counter = 0  /* start at 0 */

do while (lines(LocFile))  /* as long as we have lines left */
 NextLine = linein(LocFile)  /* get the next one */
 if (NextLine >< '') then  /* if the line is not empty */
 do
  if (substr(NextLine,1,1) >< '#') then  /* if it is not a comment */
  do
   Counter = Counter + 1  /* up the counter */
   parse var NextLine Locations.Counter ' = ' UserNames.Counter ';'  /* get the bits we want */
  end
 end
end

call stream LocFile,'C','CLOSE'  /* close the locations file */

/**********************************************************************/
/* Get user input for each of the locations we found                  */
/**********************************************************************/

do Index = 1 to Counter  /* run through the results */
 say ''  /* empty line */

 say 'User = "'||UserNames.Index||'"'  /* report the user name */
 say 'Main = "'||Locations.Index||'"'  /* report the main folder name */
 call charout StdOut,'Lock/Unlock/Skip? [L/U/S] S'||d2c(8)  /* prompt the user */
 Reply = sysgetkey('ECHO')  /* get a response */

 say ''  /* skip to the next line */

 if (pos(Reply,'Ll') > 0) then  /* if it is L(ock) */
 do
  say 'Locking "'||Locations.index||'"'  /* report */
  Action = 'YES'  /* do it */
  call LockUnlockIt  /* do it */
 end

 if (pos(Reply,'Uu') > 0) then  /* if it is U(nlock) */
 do
  say 'Unlocking "'||Locations.index||'"'  /* report */
  Action = 'NO'  /* undo it */
  call LockUnlockIt  /* do it */
 end

end

call Halt  /* that's all, folks! */

/*****************************************************************/
LockUnlockIt:  /* does the actual locking/unlocking */
/*****************************************************************/

Settings = 'NODELETE='||Action||';'||,  /* include the NoDelete setting for the next bunch of folders */
           'NOSETTINGS='||Action||';'||,  /* and NoSettings */
           'NOSHADOW='||Action||';'||,  /* and NoShadow */
           'NOCOPY='||Action||';'||,  /* and NoCopy */
           'NODRAG='||Action||';'||,  /* and NoDRag */
           'NOMOVE='||Action||';'||,  /* and NoMove */
           'NODROP='||Action||';'  /* and NoDrop */

call syssetobjectdata Locations.Index,Settings  /* process the main folder */
call syssetobjectdata Locations.Index||'\accessories',Settings  /* process the Accessories folder */
call syssetobjectdata Locations.Index||'\configuration',Settings  /* process the Configuration folder */
call syssetobjectdata Locations.Index||'\addresses',Settings  /* process the Addresses folder */

call sysfiletree Locations.Index||'\addresses\*','Folders.','DOS'  /* look for (sub)folders in the Addresses folder */
do Number = 1 to Folders.0  /* take each one we find */
 call syssetobjectdata Folders.Number,Settings  /* and process it */
end

Settings = 'NODELETE='||Action||';'||,  /* include the NoDelete setting for the next bunch of folders */
           'NOSETTINGS='||Action||';'||,  /* and NoSettings */
           'NOSHADOW='||Action||';'||,  /* and NoShadow */
           'NOCOPY='||Action||';'||,  /* and NoCopy */
           'NODRAG='||Action||';'||,  /* and NoDRag */
           'NOMOVE='||Action||';'  /* and NoMove */

call syssetobjectdata Locations.Index||'\in',Settings  /* process the In folder */
call syssetobjectdata Locations.Index||'\in archive',Settings  /* process the In Archive folder */
call syssetobjectdata Locations.Index||'\out',Settings  /* process the Out folder */
call syssetobjectdata Locations.Index||'\out archive',Settings  /* process the Out Archive folder */

return  /* end of LockUnlockIt */

/*****************************************************************/
Halt:  /* we end up here */
/*****************************************************************/

exit  /* and exit */
